@@ -7,23 +7,24 @@
 
 #include "kdf_version.h"
 #include <KAboutData>
-#include <KXMLGUIFactory>
-#include <KStandardShortcut>
-#include <KStandardAction>
 #include <KActionCollection>
+#include <KCrash>
 #include <KLocalizedString>
+#include <KStandardAction>
+#include <KStandardShortcut>
+#include <KXMLGUIFactory>
 
 #include <QApplication>
 #include <QCommandLineParser>
 
 /***************************************************************/
 KDFTopLevel::KDFTopLevel(QWidget *)
-        : KXmlGuiWindow(nullptr)
+    : KXmlGuiWindow(nullptr)
 {
-    kdf = new KDFWidget(this,false);
+    kdf = new KDFWidget(this, false);
     Q_CHECK_PTR(kdf);
-    QAction *action = actionCollection()->addAction( QStringLiteral("updatedf"));
-    action->setText( i18nc( "Update action", "&Update" ) );
+    QAction *action = actionCollection()->addAction(QStringLiteral("updatedf"));
+    action->setText(i18nc("Update action", "&Update"));
     actionCollection()->setDefaultShortcuts(action, KStandardShortcut::reload());
     connect(action, &QAction::triggered, kdf, &KDFWidget::updateDF);
 
@@ -39,7 +40,7 @@ KDFTopLevel::KDFTopLevel(QWidget *)
 /***************************************************************/
 int main(int argc, char **argv)
 {
-    //Fixes blurry icons with fractional scaling
+    // Fixes blurry icons with fractional scaling
     QApplication app(argc, argv);
 
     KLocalizedString::setApplicationDomain(QByteArrayLiteral("kdf"));
@@ -52,12 +53,9 @@ int main(int argc, char **argv)
                          i18n("(c) 1998-2001, Michael Kropfberger"),
                          QString(),
                          QStringLiteral("https://apps.kde.org/kdf"),
-                         QString()
-                        );
+                         QString());
 
-    aboutData.addAuthor(i18nc("@info:credit", "Michael Kropfberger"),
-                        QString(),
-                        QStringLiteral("michael.kropfberger@gmx.net"));
+    aboutData.addAuthor(i18nc("@info:credit", "Michael Kropfberger"), QString(), QStringLiteral("michael.kropfberger@gmx.net"));
 
     QCommandLineParser parser;
     parser.setApplicationDescription(aboutData.shortDescription());
@@ -67,23 +65,22 @@ int main(int argc, char **argv)
     KAboutData::setApplicationData(aboutData);
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("kdf")));
 
+    KCrash::initialize();
+
     // do the command line parsing
     parser.process(app);
 
     // handle standard options
     aboutData.processCommandLine(&parser);
 
-    if( app.isSessionRestored() ) //SessionManagement
+    if (app.isSessionRestored()) // SessionManagement
     {
-        for( int n=1; KDFTopLevel::canBeRestored(n); n++ )
-        {
+        for (int n = 1; KDFTopLevel::canBeRestored(n); n++) {
             KDFTopLevel *ktl = new KDFTopLevel();
             Q_CHECK_PTR(ktl);
             ktl->restore(n);
         }
-    }
-    else
-    {
+    } else {
         KDFTopLevel *ktl = new KDFTopLevel();
         Q_CHECK_PTR(ktl);
         ktl->show();
@@ -92,6 +89,4 @@ int main(int argc, char **argv)
     return app.exec();
 }
 
-
-
 #include "moc_kdf.cpp"
